==> kubernetes-model-1.0.54-sources.jar: io/fabric8/kubernetes/api/model/ComponentConditionBuilder.java <==
package io.fabric8.kubernetes.api.model;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
import javax.validation.Validation;
import javax.validation.Validator;
import javax.validation.ValidatorFactory;
import javax.validation.ValidationException;
import javax.validation.ConstraintViolation;
import javax.validation.ConstraintViolationException;
import java.util.Set;
import java.lang.Object;

public class ComponentConditionBuilder extends ComponentConditionFluentImpl<ComponentConditionBuilder> implements VisitableBuilder<ComponentCondition,ComponentConditionBuilder>{

    ComponentConditionFluent<?> fluent;
    Boolean validationEnabled;

    public ComponentConditionBuilder(){
            this(true);
    }
    public ComponentConditionBuilder(Boolean validationEnabled){
            this(new ComponentCondition(), validationEnabled);
    }
    public ComponentConditionBuilder(ComponentConditionFluent<?> fluent){
            this(fluent, true);
    }
    public ComponentConditionBuilder(ComponentConditionFluent<?> fluent,Boolean validationEnabled){
            this(fluent, new ComponentCondition(), validationEnabled);
    }
    public ComponentConditionBuilder(ComponentConditionFluent<?> fluent,ComponentCondition instance){
            this(fluent, instance, true);
    }
    public ComponentConditionBuilder(ComponentConditionFluent<?> fluent,ComponentCondition instance,Boolean validationEnabled){
            this.fluent = fluent; 
            fluent.withError(instance.getError()); 
            fluent.withMessage(instance.getMessage()); 
            fluent.withStatus(instance.getStatus()); 
            fluent.withType(instance.getType()); 
            this.validationEnabled = validationEnabled; 
    }
    public ComponentConditionBuilder(ComponentCondition instance){
            this(instance,true);
    }
    public ComponentConditionBuilder(ComponentCondition instance,Boolean validationEnabled){
            this.fluent = this; 
            this.withError(instance.getError()); 
            this.withMessage(instance.getMessage()); 
            this.withStatus(instance.getStatus()); 
            this.withType(instance.getType()); 
            this.validationEnabled = validationEnabled; 
    }

    public ComponentCondition build(){
            ComponentCondition buildable = new ComponentCondition(fluent.getError(),fluent.getMessage(),fluent.getStatus(),fluent.getType());
            validate(buildable);
            return buildable;
    }

    private <T>void validate(T item){
            if (!validationEnabled) { return; }
            Validator validator = null;
            try {
                ValidatorFactory factory = Validation.buildDefaultValidatorFactory();
                validator = factory.getValidator();
            } catch(ValidationException e) {return;}
            Set<ConstraintViolation<T>> violations = validator.validate(item);
            if (!violations.isEmpty()) {
            throw new ConstraintViolationException(violations);
             }
    }

    public boolean equals(Object o){
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;
            if (!super.equals(o)) return false;
            ComponentConditionBuilder that = (ComponentConditionBuilder) o;
            if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

            if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
            return true;
    }




}

==> kubernetes-model-1.0.64-sources.jar: io/fabric8/kubernetes/api/model/ComponentConditionBuilder.java <==
package io.fabric8.kubernetes.api.model;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import javax.annotation.Generated;
import lombok.EqualsAndHashCode;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.databind.annotation.JsonDeserialize;
import java.lang.Object;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import java.lang.Boolean;
import lombok.ToString;
import io.sundr.builder.annotations.Buildable;

public class ComponentConditionBuilder extends ComponentConditionFluentImpl<ComponentConditionBuilder> implements VisitableBuilder<ComponentCondition,ComponentConditionBuilder>{

    ComponentConditionFluent<?> fluent;
    Boolean validationEnabled;

    public ComponentConditionBuilder(){
            this(true);
    }
    public ComponentConditionBuilder(Boolean validationEnabled){
            this(new ComponentCondition(), validationEnabled);
    }
    public ComponentConditionBuilder(ComponentConditionFluent<?> fluent){
            this(fluent, true);
    }
    public ComponentConditionBuilder(ComponentConditionFluent<?> fluent,Boolean validationEnabled){
            this(fluent, new ComponentCondition(), validationEnabled);
    }
    public ComponentConditionBuilder(ComponentConditionFluent<?> fluent,ComponentCondition instance){
            this(fluent, instance, true);
    }
    public ComponentConditionBuilder(ComponentConditionFluent<?> fluent,ComponentCondition instance,Boolean validationEnabled){
            this.fluent = fluent; 
            fluent.withError(instance.getError()); 
            fluent.withMessage(instance.getMessage()); 
            fluent.withStatus(instance.getStatus()); 
            fluent.withType(instance.getType()); 
            this.validationEnabled = validationEnabled; 
    }
    public ComponentConditionBuilder(ComponentCondition instance){
            this(instance,true);
    }
    public ComponentConditionBuilder(ComponentCondition instance,Boolean validationEnabled){
            this.fluent = this; 
            this.withError(instance.getError()); 
            this.withMessage(instance.getMessage()); 
            this.withStatus(instance.getStatus()); 
            this.withType(instance.getType()); 
            this.validationEnabled = validationEnabled; 
    }

    public ComponentCondition build(){
            ComponentCondition buildable = new ComponentCondition(fluent.getError(),fluent.getMessage(),fluent.getStatus(),fluent.getType());
            io.fabric8.kubernetes.api.builder.ValidationUtils.validate(buildable);
            return buildable;
    }

    public boolean equals(Object o){
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;
            if (!super.equals(o)) return false;
            ComponentConditionBuilder that = (ComponentConditionBuilder) o;
            if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

            if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
            return true;
    }




}
